:mod:`{{module}}`.{{objname}}
{{ underline }}====================

.. currentmodule:: {{ module }}

.. autofunction:: {{ objname }}

Bibliography
------------
.. bibliography:: ../kernels/graph_kernels.bib
   :filter: docname in docnames

.. include:: {{module}}.{{objname}}.examples

.. raw:: html

    <div class="clearer"></div>

